#
# spec file for package patterns-hpc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           patterns-hpc
Version:        20180416
Release:        lp150.3.1
Summary:        Source Package for HPC Patterns
License:        MIT
Group:          Metapackages
Url:            https://github.com/openSUSE/patterns
Source0:        %{name}-rpmlintrc
Source1:        library-inc.txt
Source2:        devel-inc.txt
BuildRequires:  patterns-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64 aarch64

%description
This is an internal package that is used to create the patterns as part of 
the installation source setup.  Installation of this package does not make
sense.
This particular package contains all the HPC related patterns.

################################################################################

%package compute_node
%pattern_serverfunctions
Summary:        HPC Basic Compute Node
Group:          Metapackages
Provides:       pattern() = hpc_compute_node
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-visible()

Requires:       nfs-client
Requires:       openssh
Requires:       sudo

Recommends:     vim
Recommends:     salt-minion
Recommends:     slurm-node
Recommends:     ypbind
Recommends:     rsync
Recommends:     wget
Recommends:     ntp
Recommends:     less
Recommends:     pdsh
Recommends:     mrsh
Recommends:     mrsh-server
%if 0%{?is_opensuse}
Recommends:     nss_ldap
%endif
# python 2.7 deps
Recommends:     ganglia-gmond
Recommends:     genders
Recommends:     perl-genders

%description compute_node
A compute node comprises of a minimal software image and mainly runs simulation programs. Services on this node should be reduced to a bare minimum and the node *must* be installed in a automatic manner.  
The pattern 'HPC modularized libraries' should also be installed.

%files compute_node
%dir %{_defaultdocdir}/patterns
%{_defaultdocdir}/patterns/patterns-hpc-compute_node.txt

################################################################################

%package libraries
%pattern_serverfunctions
Summary:        HPC modularized Libraries
Group:          Metapackages
Provides:       pattern() = hpc_libraries
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2030
Provides:       pattern-visible()
Requires:       pattern() = hpc_compute_node

Requires:       lua-lmod
%include %{SOURCE1}

%description libraries
This package provides all the modularized libraries so that they can be used in an HPC environment. These libraries allow to install several MPI flavors in parallel.
In order to use thess libraries one needs to load them via the module command first.

%files libraries
%dir %{_defaultdocdir}/patterns
%{_defaultdocdir}/patterns/patterns-hpc-libraries.txt

################################################################################
%package development_node
%pattern_development
Summary:        HPC Development Packages
Group:          Metapackages
Provides:       pattern() = hpc_development_node
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 2040
Provides:       pattern-visible()
Requires:       pattern() = hpc_compute_node
Requires:       pattern() = hpc_libraries
%if 0%{?is_opensuse}
Requires:       pattern() = devel_C_C++
Requires:       pattern() = devel_basis
Requires:       pattern() = devel_perl
Requires:       pattern() = devel_python3
%else
Requires:       pattern() = devel_basis
Recommends:     python3
Recommends:     python3-devel
%endif
Requires:       gnu-compilers-hpc-devel
Requires:       lua-lmod
%include %{SOURCE2}

%description development_node
This package provides all the relevant packages for developing HPC applications.
It depends on the pattern 'HPC modularized libraries'. In addition it includes the GNU compilers and the relevant management packages.

%files development_node
%dir %{_defaultdocdir}/patterns
%{_defaultdocdir}/patterns/patterns-hpc-development_node.txt

################################################################################
%package workload_server
%pattern_serverfunctions
Summary:        HPC Workload Manager
Group:          Metapackages
Provides:       pattern() = hpc_workload_server
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-visible()

Recommends:     slurm
Recommends:     slurm-slurmdbd
Suggests:       mariadb

%description workload_server
This package provides all the relevant packages for running the central server 
component of the slurm workload manager.

%files workload_server
%dir %{_defaultdocdir}/patterns
%{_defaultdocdir}/patterns/patterns-hpc-workload_server.txt

%prep

%build

%install
mkdir -p "%{buildroot}%{_defaultdocdir}/patterns"
for pack in patterns-hpc-compute_node patterns-hpc-libraries \
        patterns-hpc-workload_server patterns-hpc-development_node; do
    echo "This file marks the pattern $pack in version %{version} to be installed." \
		>"%{buildroot}%{_defaultdocdir}/patterns/${pack}.txt"
done

%changelog
* Fri May  4 2018 cgoll@suse.com
- added openmpi2 documentation package (bsc#1091714)
* Fri Apr 20 2018 eich@suse.com
- Fix new pattern workload_server: add missing provides
  (bsc#1089511).
* Mon Apr 16 2018 eich@suse.com
- Fixed wordings in some descriptions (bsc#1089719).
* Fri Apr 13 2018 cgoll@suse.com
- created new pattern workload_server for slurmctld (bsc#1089511)
* Tue Apr 10 2018 cgoll@suse.com
- added mrsh-server as recommended as bug fix for bsc#1088689
* Wed Apr  4 2018 cgoll@suse.com
- added sudo to the hpc_compute_node pattern (bsc#1087938)
- added slurm-node as recommends to the hpc_compute_node
  (bsc#1087940)
- added ypbind to the hpc_compute_node pattern (bsc#1087935)
- replaced explcit requires with the pattern devel_basis
* Tue Mar 27 2018 cgoll@suse.com
- removed mvapich-psm package as requires for hpc_library and
  mvapich2-psm2 is only recommended for x86_64 (bsc#1087038)
- removed tau libraries and parallel netcdf-devel libraries
* Mon Mar 26 2018 eich@suse.com
- Prepended HPC to 'Summary' tags to make sure
  entries are nicely sorted on YaST.
- Made sure entries were brief (bsc1086828).
* Mon Mar 26 2018 cgoll@suse.com
- made compute node pattern visible (bsc#1086828)
- fixed typos
* Mon Mar  5 2018 cgoll@suse.com
- fixed wrong 'Provides: Metapackage'
* Fri Mar  2 2018 cgoll@suse.com
- fixed (bsc#1083728) opempi3 patterns in development node
* Fri Mar  2 2018 cgoll@suse.com
- added more libraries and fixed the names
* Mon Feb 26 2018 cgoll@suse.com
- removed openmpi3 pattern and warning about explict library dep
* Sat Feb 24 2018 eich@suse.com
- Fix Group name.
- Move library file list to an include file.
- General clean up and bug fixes.
* Fri Feb 23 2018 eich@suse.com
- Initial package version of patterns for HPC (FATE#323494).
